@@ -14,7 +14,7 @@ gi.require_version("Gdk", "4.0")
 gi.require_version("GtkSource", "5")
 gi.require_version("Adw", "1")
 
-from gi.repository import Adw, Gio, GtkSource
+from gi.repository import Adw, Gio, GLib, Gtk, GtkSource
 
 import gaphor.asyncio
 import gaphor.ui.diagramview  # noqa: F401
@@ -30,9 +30,18 @@ Adw.init()
 GtkSource.init()
 
 
-def run(argv: list[str], *, launch_service="greeter", recover=False) -> int:
+def run(argv: list[str], *, launch_service="greeter", recover=False) -> int:  # noqa: C901
     application: Application | None = None
 
+    def app_handle_local_options(gtk_app, options):
+        if options.contains("greeter"):
+            gtk_app.register()
+            if gtk_app.get_property("is-remote"):
+                gtk_app.activate_action("new-window")
+                return 0
+
+        return -1
+
     def app_startup(gtk_app):
         nonlocal application
 
@@ -72,6 +81,8 @@ def run(argv: list[str], *, launch_service="greeter", recover=False) -> int:
         assert application
         if not application.sessions:
             application.get_service(launch_service).open()
+        elif gtk_app.get_active_window():
+            gtk_app.get_active_window().present()
 
     def app_open(gtk_app, files, n_files, hint):
         # appfilemanager should take care of this:
@@ -99,6 +110,17 @@ def run(argv: list[str], *, launch_service="greeter", recover=False) -> int:
 
     settings.style_variant_changed(update_color_scheme)
     gtk_app.exit_code = 0
+
+    gtk_app.add_main_option(
+        "greeter",
+        b"g",
+        GLib.OptionFlags.NONE,
+        GLib.OptionArg.NONE,
+        "Create a new model",
+        None,
+    )
+
+    gtk_app.connect("handle-local-options", app_handle_local_options)
     gtk_app.connect("startup", app_startup)
     gtk_app.connect("activate", app_activate)
     gtk_app.connect("open", app_open)
